@@ -2,16 +2,20 @@
 #![allow(
     clippy::cast_sign_loss,
     clippy::default_trait_access,
+    clippy::elidable_lifetime_names,
     clippy::enum_glob_use,
+    clippy::expl_impl_clone_on_copy, // https://github.com/rust-lang/rust-clippy/issues/15842
     clippy::inherent_to_string,
     clippy::items_after_statements,
     clippy::map_clone,
     clippy::match_bool,
-    clippy::match_on_vec_items,
+    clippy::match_like_matches_macro,
     clippy::match_same_arms,
+    clippy::needless_continue,
     clippy::needless_lifetimes,
     clippy::needless_pass_by_value,
     clippy::nonminimal_bool,
+    clippy::precedence,
     clippy::redundant_else,
     clippy::ref_option,
     clippy::similar_names,
@@ -23,6 +27,7 @@
     clippy::toplevel_ref_arg,
     clippy::uninlined_format_args
 )]
+#![allow(unknown_lints, mismatched_lifetime_syntaxes)]
 
 mod app;
 mod cfg;
